/**
 *
 */
package org.jboss.cache.eviction;

import org.jboss.cache.CacheSPI;
import org.jboss.cache.Fqn;
import org.jboss.cache.config.Configuration;
import org.jboss.cache.config.EvictionAlgorithmConfig;
import org.jboss.cache.eviction.EvictionEvent.Type;

import java.util.concurrent.BlockingQueue;

/**
 * An eviction algorithm that does nothing - a no-op for everything.
 *
 * @author Brian Stansberry
 */
public class NullEvictionAlgorithm implements EvictionAlgorithm
{
   /**
    * Singleton instance of this class.
    */
   private static final NullEvictionAlgorithm INSTANCE = new NullEvictionAlgorithm();

   /**
    * Constructs a new NullEvictionAlgorithm.
    */
   private NullEvictionAlgorithm()
   {
   }

   public static NullEvictionAlgorithm getInstance()
   {
      return INSTANCE;
   }

   /**
    * Returns {@link NullEvictionQueue#INSTANCE}.
    */
   public EvictionQueue getEvictionQueue()
   {
      return NullEvictionQueue.INSTANCE;
   }

   public void setEvictionActionPolicy(EvictionActionPolicy evictionActionPolicy)
   {
      // no-op
   }

   public void assignToRegion(Fqn fqn, CacheSPI<?, ?> cache, EvictionAlgorithmConfig evictionAlgorithmConfig, Configuration configuration)
   {
      // no-op
   }

   public void process(BlockingQueue<EvictionEvent> queue) throws EvictionException
   {
      // no-op
   }

   public void resetEvictionQueue()
   {
      // no-op
   }

   public boolean canIgnoreEvent(Type eventType)
   {
      return true; // always ignore everything!
   }

   public void initialize()
   {
      // no-op
   }

   public Class<? extends EvictionAlgorithmConfig> getConfigurationClass()
   {
      return NullEvictionAlgorithmConfig.class;
   }
}
