package org.jboss.cache.eviction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jboss.cache.Cache;
import org.jboss.cache.Fqn;

/**
 * An eviction action policy that calls {@link org.jboss.cache.Cache#removeNode(org.jboss.cache.Fqn)} to evict a node.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public class RemoveOnEvictActionPolicy implements EvictionActionPolicy
{
   Cache<?, ?> cache;
   private static final Log log = LogFactory.getLog(DefaultEvictionActionPolicy.class);

   public void setCache(Cache<?, ?> cache)
   {
      this.cache = cache;
   }

   public boolean evict(Fqn fqn)
   {
      try
      {
         return cache.removeNode(fqn);
      }
      catch (Exception e)
      {
         if (log.isDebugEnabled()) log.debug("Unable to evict " + fqn, e);
         return false;
      }
   }
}