package org.jboss.cache.factories;

import org.jboss.cache.config.ConfigurationException;
import org.jboss.cache.factories.annotations.DefaultFactoryFor;
import org.jboss.cache.factories.context.ContextFactory;
import org.jboss.cache.factories.context.MVCCContextFactory;
import org.jboss.cache.factories.context.OptimisticContextFactory;
import org.jboss.cache.factories.context.PessimisticContextFactory;

/**
 * Responsible for creating the appropriate {@link org.jboss.cache.factories.context.ContextFactory} based on configuration used.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
@DefaultFactoryFor(classes = ContextFactory.class)
public class ContextMetaFactory extends ComponentFactory
{
   @SuppressWarnings("deprecation")
   protected <T> T construct(Class<T> componentType)
   {
      if (log.isTraceEnabled()) log.trace("Cache configuration is " + configuration.getNodeLockingScheme());
      switch (configuration.getNodeLockingScheme())
      {
         case MVCC:
            if (log.isTraceEnabled()) log.trace("Creating an MVCC context factory");
            return componentType.cast(new MVCCContextFactory());
         case OPTIMISTIC:
            if (log.isTraceEnabled()) log.trace("Creating an optimistic context factory");
            return componentType.cast(new OptimisticContextFactory());
         case PESSIMISTIC:
            if (log.isTraceEnabled()) log.trace("Creating a pessimistic context factory");
            return componentType.cast(new PessimisticContextFactory());
      }
      throw new ConfigurationException("Unknown configuration node locking scheme");
   }
}
