/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.config.ConfigurationException;
import org.jboss.cache.config.parsing.XmlConfigHelper;
import org.jboss.cache.config.parsing.element.EvictionElementParser;
import static org.testng.AssertJUnit.*;
import org.testng.annotations.Test;
import org.w3c.dom.Element;

/**
 * @author Daniel Huang
 * @version $Revision: 6574 $
 */
@Test(groups = "unit", sequential = false)
public class ElementSizeConfigurationTest
{
   public void testXMLParse1() throws Exception
   {
      ElementSizeAlgorithmConfig config = new ElementSizeAlgorithmConfig();
      String xml = "<region name=\"abc\">" +
            "<attribute name=\"maxNodes\">1000</attribute>" +
            "<attribute name=\"maxElementsPerNode\">100</attribute>" +
            "</region>";

      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);
      EvictionElementParser.parseEvictionPolicyConfig(element, config);
      config.validate();

      assertEquals(100, config.getMaxElementsPerNode());
      assertEquals(1000, config.getMaxNodes());
   }


   public void testXMLParse2() throws Exception
   {
      ElementSizeAlgorithmConfig config = new ElementSizeAlgorithmConfig();
      String xml = "<region name=\"abc\">" +
            "<attribute name=\"maxNodes\">1000</attribute>" +
            "</region>";

      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);
      try
      {
         EvictionElementParser.parseEvictionPolicyConfig(element, config);
         config.validate();
      }
      catch (ConfigurationException ce)
      {
         assertTrue("Configure exception properly thrown", true);
         return;
      }

      fail("Invalid region Element Size configuration did not cause ConfigureException to be thrown with empty maxElementsPerNode attribute");
   }


   public void testXMLParse3() throws Exception
   {
      ElementSizeAlgorithmConfig config = new ElementSizeAlgorithmConfig();
      String xml = "<region name=\"abc\">" +
            "<attribute name=\"maxElementsPerNode\">100</attribute>" +
            "</region>";

      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);

      EvictionElementParser.parseEvictionPolicyConfig(element, config);
      config.validate();

      assertEquals(100, config.getMaxElementsPerNode());
      assertEquals(0, config.getMaxNodes());
   }

}
