package org.jboss.cache.passivation;

import org.testng.annotations.Test;
import static org.jboss.cache.factories.UnitTestCacheConfigurationFactory.*;

import java.io.File;
import java.io.FileFilter;

/**
 * Runs the same tests as {@link PassivationToFileCacheLoaderTest}, but with
 * Berkeley DB instead of a file-based CacheLoader
 *
 * @author <a href="mailto:{hmesha@novell.com}">{Hany Mesha}</a>
 * @version $Id: PassivationToBdbjeCacheLoaderTest.java 6042 2008-06-25 17:04:10Z mircea.markus $
 */
@Test(groups = "functional")
public class PassivationToBdbjeCacheLoaderTest extends PassivationTestsBase
{
   private String tmp_location = System.getProperty("java.io.tmpdir", "c:\\tmp");
   private File dir = new File(tmp_location);

   public PassivationToBdbjeCacheLoaderTest()
   {
      if (!dir.exists()) dir.mkdirs();
   }

   protected void configureCache() throws Exception
   {

      class MyFilter implements FileFilter
      {
         public boolean accept(File file)
         {
            return file.getName().endsWith(".jdb");
         }
      }

      File[] files = dir.listFiles(new MyFilter());
      if (files != null)
      {
         for (int i = 0; i < files.length; i += 1)
         {
            File file = files[i];
            if (file.isFile())
            {
               if (!file.delete())
               {
                  System.err.println("Unable to delete: " + file);
               }
            }
         }
      }

      cache.getConfiguration().setCacheLoaderConfig(buildSingleCacheLoaderConfig(true, null, "org.jboss.cache.loader.bdbje.BdbjeCacheLoader", "", false, false, false, false, false));
   }
}
